@@ -8,11 +8,12 @@ import (
 	"syscall"
 )
 
-func buildCmd(cmd *exec.Cmd) error {
+func buildCmd(cmd *exec.Cmd, foreground bool) error {
 	cmd.SysProcAttr = &syscall.SysProcAttr{
 		// isolate each command in a new process group that we can cleanly send
 		// signal to when we want to stop it
-		Setpgid: true,
+		Setpgid:    true,
+		Foreground: foreground,
 	}
 
 	return nil
